@@ -1,6 +1,6 @@
 /*
   gbfun (ver. 5.6) -- Apply functions to table of data
-  Copyright (C) 2008-2014 Giulio Bottazzi
+  Copyright (C) 2008-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -95,7 +95,7 @@ int main(int argc,char* argv[]){
   
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
   
   /* START COMMAND LINE PROCESSING */
