@@ -1,6 +1,6 @@
 /*
   gbget  (ver. 5.6) -- Basic data extraction and manipulation tool
-  Copyright (C) 2011-2014 Giulio Bottazzi
+  Copyright (C) 2011-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -1299,7 +1299,7 @@ int main(int argc, char * argv[]){
   int o_verbose=0;
   
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
   /* COMMAND LINE PROCESSING */
