@@ -1,6 +1,6 @@
 /*
   gbglreg  (ver. 5.6) -- Estimate general linear regression model
-  Copyright (C) 2005-2014 Giulio Bottazzi
+  Copyright (C) 2005-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -277,7 +277,7 @@ int main(int argc,char* argv[]){
   
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
   
   /* COMMAND LINE PROCESSING */
