@@ -1,6 +1,6 @@
 /*
   gbhill (ver. 5.6) -- Hill Maximum Likelihhod estimation
-  Copyright (C) 2012-2014 Giulio Bottazzi
+  Copyright (C) 2012-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -84,7 +84,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
   /* COMMAND LINE PROCESSING */
