@@ -1,6 +1,6 @@
 /*
   gbkreg  (ver. 5.6) -- Kernel non linear regression function
-  Copyright (C) 2003-2014 Giulio Bottazzi
+  Copyright (C) 2003-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -81,7 +81,7 @@ int main(int argc,char* argv[]){
     
     /* variables for reading command line options */
     /* ------------------------------------------ */
-    char opt;
+    int opt;
     /* ------------------------------------------ */
     
     
