@@ -1,6 +1,6 @@
 /*
   gbkreg2d  (ver. 5.6) -- Kernel non linear regression for bivariate data
-  Copyright (C) 2004-2014 Giulio Bottazzi
+  Copyright (C) 2004-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -70,7 +70,7 @@ int main(int argc,char* argv[]){
     
     /* variables for reading command line options */
     /* ------------------------------------------ */
-    char opt;
+    int opt;
     /* ------------------------------------------ */
     
     
