@@ -3,7 +3,7 @@
   data using direct (and slow) kernel computation with Silverman
   method and, when applicable, Hall York corrections.
 
-  Copyright (C) 2004-2014 Giulio Bottazzi
+  Copyright (C) 2004-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -346,7 +346,7 @@ int main(int argc,char* argv[]){
     
     /* variables for reading command line options */
     /* ------------------------------------------ */
-    char opt;
+    int opt;
     /* ------------------------------------------ */
     
     
