@@ -1,6 +1,6 @@
 /*
   gbnlmult (ver. 5.6) -- Solve systems of non linear simultaneous equations 
-  Copyright (C) 2007-2014 Giulio Bottazzi
+  Copyright (C) 2007-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -477,7 +477,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
   /* COMMAND LINE PROCESSING */
