@@ -1,6 +1,6 @@
 /*
   gbnlpanel  (ver. 5.6) -- Non-linear panel regression
-  Copyright (C) 2009-2014 Giulio Bottazzi and Davide Pirino
+  Copyright (C) 2009-2018 Giulio Bottazzi and Davide Pirino
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -1543,7 +1543,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
   
   /* COMMAND LINE PROCESSING */
