@@ -1,7 +1,7 @@
 /*
   gbnlpolyit (ver. 5.6) -- Non linear polyit regression
 
-  Copyright (C) 2010-2014 Giulio Bottazzi
+  Copyright (C) 2010-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -796,7 +796,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
   /* COMMAND LINE PROCESSING */
