@@ -1,6 +1,6 @@
 /*
   gbnlprobit (ver. 5.6) -- Non linear probit regression
-  Copyright (C) 2009-2014 Giulio Bottazzi
+  Copyright (C) 2009-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -757,7 +757,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
   /* COMMAND LINE PROCESSING */
