@@ -1,6 +1,6 @@
 /*
   gbquant  (ver. 5.6.1) -- Print quantiles of data distribution
-  Copyright (C) 2004-2014 Giulio Bottazzi
+  Copyright (C) 2004-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -40,7 +40,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
   /* COMMAND LINE PROCESSING */    
