@@ -1,6 +1,6 @@
 /*
   gbstat  (ver. 5.6) -- Basic descriptive statistics of data
-  Copyright (C) 2000-2014 Giulio Bottazzi
+  Copyright (C) 2000-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -88,7 +88,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
   /* set default output */
