@@ -1,7 +1,7 @@
 /*
   gbtest (ver. 5.6) -- Compute statistical tests on data
 
-  Copyright (C) 2011-2014 Giulio Bottazzi
+  Copyright (C) 2011-2018 Giulio Bottazzi
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -2378,7 +2378,7 @@ int main(int argc,char* argv[]){
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
-  char opt;
+  int opt;
   /* ------------------------------------------ */
 
 
